/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlschaltprogramm.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Definiert den aktuellen Zustand eines
					Schaltprogramms.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class AttSchaltProgrammZustand extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttSchaltProgrammZustand ZUSTAND_2N_GELOESCHT = new AttSchaltProgrammZustand("Gelöscht", 		Byte
	.valueOf("-2"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttSchaltProgrammZustand ZUSTAND_1N_UNBEKANNT = new AttSchaltProgrammZustand("Unbekannt", 		Byte
	.valueOf("-1"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttSchaltProgrammZustand ZUSTAND_0_BEREIT = new AttSchaltProgrammZustand("Bereit", 		Byte
	.valueOf("0"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttSchaltProgrammZustand ZUSTAND_1_WIRD_BEARBEITET = new AttSchaltProgrammZustand("Wird bearbeitet", 		Byte
	.valueOf("1"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttSchaltProgrammZustand ZUSTAND_2_WARTEND = new AttSchaltProgrammZustand("Wartend", 		Byte
	.valueOf("2"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttSchaltProgrammZustand ZUSTAND_3_AKTIV = new AttSchaltProgrammZustand("Aktiv", 		Byte
	.valueOf("3"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttSchaltProgrammZustand getZustand(final 		Byte
	 value) {
		for (AttSchaltProgrammZustand e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttSchaltProgrammZustand getZustand(final String value) {
		for (AttSchaltProgrammZustand e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttSchaltProgrammZustand> getZustaende() {
		List<AttSchaltProgrammZustand> list = new ArrayList<AttSchaltProgrammZustand>();
		list.add(ZUSTAND_2N_GELOESCHT);
		list.add(ZUSTAND_1N_UNBEKANNT);
		list.add(ZUSTAND_0_BEREIT);
		list.add(ZUSTAND_1_WIRD_BEARBEITET);
		list.add(ZUSTAND_2_WARTEND);
		list.add(ZUSTAND_3_AKTIV);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut .
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttSchaltProgrammZustand(final 		Byte
	 value) {
		super(value);
	}
	
	private AttSchaltProgrammZustand(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
