/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.systemmodellkexdav.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Strategie beim Austausch von Parameterdaten.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class AttParameterdatenStrategie extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttParameterdatenStrategie ZUSTAND_1_LOKALE_VERWALTUNG_REMOTE_LESEN = new AttParameterdatenStrategie("Lokale Verwaltung, Remote lesen", 		Byte
	.valueOf("1"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttParameterdatenStrategie ZUSTAND_2_LOKALE_VERWALTUNG_REMOTE_LESEN_UND_AENDERN = new AttParameterdatenStrategie("Lokale Verwaltung, Remote lesen und ändern", 		Byte
	.valueOf("2"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttParameterdatenStrategie ZUSTAND_3_REMOTE_VERWALTUNG_LOKAL_LESEN = new AttParameterdatenStrategie("Remote Verwaltung, Lokal lesen", 		Byte
	.valueOf("3"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttParameterdatenStrategie ZUSTAND_4_REMOTE_VERWALTUNG_LOKAL_LESEN_UND_AENDERN = new AttParameterdatenStrategie("Remote Verwaltung, Lokal lesen und ändern", 		Byte
	.valueOf("4"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttParameterdatenStrategie ZUSTAND_5_VERWALTUNG_IM_LOKAL_UND_REMOTE_SYSTEM = new AttParameterdatenStrategie("Verwaltung im Lokal und Remote-System", 		Byte
	.valueOf("5"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttParameterdatenStrategie ZUSTAND_6_VERWALTUNG_IM_LOKAL_UND_REMOTE_SYSTEM_MIT_TRIGGER = new AttParameterdatenStrategie("Verwaltung im Lokal und Remote-System mit Trigger", 		Byte
	.valueOf("6"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttParameterdatenStrategie getZustand(final 		Byte
	 value) {
		for (AttParameterdatenStrategie e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttParameterdatenStrategie getZustand(final String value) {
		for (AttParameterdatenStrategie e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttParameterdatenStrategie> getZustaende() {
		List<AttParameterdatenStrategie> list = new ArrayList<AttParameterdatenStrategie>();
		list.add(ZUSTAND_1_LOKALE_VERWALTUNG_REMOTE_LESEN);
		list.add(ZUSTAND_2_LOKALE_VERWALTUNG_REMOTE_LESEN_UND_AENDERN);
		list.add(ZUSTAND_3_REMOTE_VERWALTUNG_LOKAL_LESEN);
		list.add(ZUSTAND_4_REMOTE_VERWALTUNG_LOKAL_LESEN_UND_AENDERN);
		list.add(ZUSTAND_5_VERWALTUNG_IM_LOKAL_UND_REMOTE_SYSTEM);
		list.add(ZUSTAND_6_VERWALTUNG_IM_LOKAL_UND_REMOTE_SYSTEM_MIT_TRIGGER);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut .
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttParameterdatenStrategie(final 		Byte
	 value) {
		super(value);
	}
	
	private AttParameterdatenStrategie(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
