/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Zustand der Fahrbahnoberfläche für den Winterdienst.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 22
 */
@Wertebereich(
	minimum = 0L,
	maximum = 254L,
	einheit = ""
)
public class AttTlsUfdZustandFahrbahnoberflaecheWinterdienst extends Zahl<		Short
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Short
	 MIN_VALUE =
				Short
		.valueOf("0");
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Short
	 MAX_VALUE =
				Short
		.valueOf("254");
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "";
	
	/**
	Die Fahrbahnfläche ist visuell trocken.
	<p>
	
	</p>
	*/
	public static final AttTlsUfdZustandFahrbahnoberflaecheWinterdienst ZUSTAND_0_TROCKEN = new AttTlsUfdZustandFahrbahnoberflaecheWinterdienst("trocken", 		Short
	.valueOf("0"));

	/**
	Auf der Fahrbahnoberfläche ist ein Wasserfilm vo mindestens 0,01 mm vorhanden.
	<p>
	
	</p>
	*/
	public static final AttTlsUfdZustandFahrbahnoberflaecheWinterdienst ZUSTAND_16_FEUCHT = new AttTlsUfdZustandFahrbahnoberflaecheWinterdienst("feucht", 		Short
	.valueOf("16"));

	/**
	Auf der Fahrbahnoberfläche ist ein Wasserfilm vo mindestens 0,2 mm vorhanden.
	<p>
	
	</p>
	*/
	public static final AttTlsUfdZustandFahrbahnoberflaecheWinterdienst ZUSTAND_32_NASS = new AttTlsUfdZustandFahrbahnoberflaecheWinterdienst("nass", 		Short
	.valueOf("32"));

	/**
	Auf der Fahrbahnoberfläche ist ein Wasserfilm vo mindestens 2 mm vorhanden.
	<p>
	
	</p>
	*/
	public static final AttTlsUfdZustandFahrbahnoberflaecheWinterdienst ZUSTAND_48_EXTREM_NASS = new AttTlsUfdZustandFahrbahnoberflaecheWinterdienst("extrem nass", 		Short
	.valueOf("48"));

	/**
	Eis, Schnee und Reif bzw. wässrige Lösungen im festen Zustand auch neben Wasser bzw. wässrigen Lösungen befinden sich auf der Fahrbahnoberfläche.
	<p>
	
	</p>
	*/
	public static final AttTlsUfdZustandFahrbahnoberflaecheWinterdienst ZUSTAND_64_GLATT = new AttTlsUfdZustandFahrbahnoberflaecheWinterdienst("glatt", 		Short
	.valueOf("64"));

	/**
	Sensorik kann auf Grund der herrschenden
								Bedingungen Zustand nicht bestimmen.
	<p>
	
	</p>
	*/
	public static final AttTlsUfdZustandFahrbahnoberflaecheWinterdienst ZUSTAND_255_NICHT_ERMITTELBAR = new AttTlsUfdZustandFahrbahnoberflaecheWinterdienst("nicht ermittelbar", 		Short
	.valueOf("255"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttTlsUfdZustandFahrbahnoberflaecheWinterdienst getZustand(final 		Short
	 value) {
		for (AttTlsUfdZustandFahrbahnoberflaecheWinterdienst e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttTlsUfdZustandFahrbahnoberflaecheWinterdienst getZustand(final String value) {
		for (AttTlsUfdZustandFahrbahnoberflaecheWinterdienst e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttTlsUfdZustandFahrbahnoberflaecheWinterdienst> getZustaende() {
		List<AttTlsUfdZustandFahrbahnoberflaecheWinterdienst> list = new ArrayList<AttTlsUfdZustandFahrbahnoberflaecheWinterdienst>();
		list.add(ZUSTAND_0_TROCKEN);
		list.add(ZUSTAND_16_FEUCHT);
		list.add(ZUSTAND_32_NASS);
		list.add(ZUSTAND_48_EXTREM_NASS);
		list.add(ZUSTAND_64_GLATT);
		list.add(ZUSTAND_255_NICHT_ERMITTELBAR);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut TLSUfdZustandFahrbahnoberflächeWinterdienst.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttTlsUfdZustandFahrbahnoberflaecheWinterdienst(final 		Short
	 value) {
		super(value);
	}
	
	private AttTlsUfdZustandFahrbahnoberflaecheWinterdienst(final String zustand, final 		Short
	 value) {
		super(zustand, value);
	}
	
}
